from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.asset import asset_pb2 as _asset_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class SearchDeletedAssetRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchDeletedAssetRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchDeletedAssetRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SearchDeletedAssetRequestBody(_message.Message):
    __slots__ = ("condition", "page")
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    condition: _asset_pb2.SearchAssetCondition
    page: _message_pb2.RequestPage
    def __init__(
        self,
        condition: _Optional[_Union[_asset_pb2.SearchAssetCondition, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class SearchDeletedAssetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchDeletedAssetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchDeletedAssetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SearchDeletedAssetResponseBody(_message.Message):
    __slots__ = ("status", "assets")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ASSETS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    assets: _containers.RepeatedCompositeFieldContainer[DeletedAssetMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        assets: _Optional[_Iterable[_Union[DeletedAssetMetadata, _Mapping]]] = ...,
    ) -> None: ...

class RecoverDeletedAssetRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: RecoverDeletedAssetRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[RecoverDeletedAssetRequestBody, _Mapping]] = ...,
    ) -> None: ...

class RecoverDeletedAssetRequestBody(_message.Message):
    __slots__ = ("hash", "namespaceId")
    HASH_FIELD_NUMBER: _ClassVar[int]
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    hash: str
    namespaceId: str
    def __init__(self, hash: _Optional[str] = ..., namespaceId: _Optional[str] = ...) -> None: ...

class RecoverDeletedAssetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: RecoverDeletedAssetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[RecoverDeletedAssetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class RecoverDeletedAssetResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class RemoveDeletedAssetRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: RemoveDeletedAssetRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[RemoveDeletedAssetRequestBody, _Mapping]] = ...,
    ) -> None: ...

class RemoveDeletedAssetRequestBody(_message.Message):
    __slots__ = ("hash", "namespaceId")
    HASH_FIELD_NUMBER: _ClassVar[int]
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    hash: str
    namespaceId: str
    def __init__(self, hash: _Optional[str] = ..., namespaceId: _Optional[str] = ...) -> None: ...

class RemoveDeletedAssetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: RemoveDeletedAssetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[RemoveDeletedAssetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class RemoveDeletedAssetResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class DeletedAssetMetadata(_message.Message):
    __slots__ = ("asset", "deletedAt")
    ASSET_FIELD_NUMBER: _ClassVar[int]
    DELETEDAT_FIELD_NUMBER: _ClassVar[int]
    asset: _asset_pb2.AssetMetadata
    deletedAt: str
    def __init__(
        self, asset: _Optional[_Union[_asset_pb2.AssetMetadata, _Mapping]] = ..., deletedAt: _Optional[str] = ...
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/warehouse/warehouse.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/warehouse/warehouse.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$yeying/api/warehouse/warehouse.proto\x12\x10yeying.api.store\x1a\x1fyeying/api/common/message.proto"1\n\x0fGetStateRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x11\n\tcondition\x18\x02 \x01(\t"E\n\x10GetStateResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x1e\n\x0fTransferRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"E\n\x10TransferResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xb5\x01\n\tWarehouse\x12S\n\x08GetState\x12!.yeying.api.store.GetStateRequest\x1a".yeying.api.store.GetStateResponse"\x00\x12S\n\x08Transfer\x12!.yeying.api.store.TransferRequest\x1a".yeying.api.store.GetStateResponse"\x00\x42\x12Z\x10yeying/api/storeb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.warehouse.warehouse_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/store"
    _globals["_GETSTATEREQUEST"]._serialized_start = 91
    _globals["_GETSTATEREQUEST"]._serialized_end = 140
    _globals["_GETSTATERESPONSE"]._serialized_start = 142
    _globals["_GETSTATERESPONSE"]._serialized_end = 211
    _globals["_TRANSFERREQUEST"]._serialized_start = 213
    _globals["_TRANSFERREQUEST"]._serialized_end = 243
    _globals["_TRANSFERRESPONSE"]._serialized_start = 245
    _globals["_TRANSFERRESPONSE"]._serialized_end = 314
    _globals["_WAREHOUSE"]._serialized_start = 317
    _globals["_WAREHOUSE"]._serialized_end = 498
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/vector/vector.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/vector/vector.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/vector/vector.proto\x12\x11yeying.api.vector\x1a\x1fyeying/api/common/message.proto"\x1c\n\rVectorRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"C\n\x0eVectorResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2X\n\x06Vector\x12N\n\x05Query\x12 .yeying.api.vector.VectorRequest\x1a!.yeying.api.vector.VectorResponse"\x00\x42\x13Z\x11yeying/api/vectorb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.vector.vector_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/vector"
    _globals["_VECTORREQUEST"]._serialized_start = 86
    _globals["_VECTORREQUEST"]._serialized_end = 114
    _globals["_VECTORRESPONSE"]._serialized_start = 116
    _globals["_VECTORRESPONSE"]._serialized_end = 183
    _globals["_VECTOR"]._serialized_start = 185
    _globals["_VECTOR"]._serialized_end = 273
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .llm_pb2 import CompleteRequest
from .llm_pb2 import CompleteRequestBody
from .llm_pb2 import Message
from .llm_pb2 import Content
from .llm_pb2 import Answer
from .llm_pb2 import CompleteResponse
from .llm_pb2 import CompleteResponseHead
from .llm_pb2 import CompleteResponseHeadBody
from .llm_pb2 import CompleteResponseBody
from .llm_pb2 import CompleteResponseTail
from .llm_pb2 import CompleteResponseTailBody
from .llm_pb2 import GenerateRequest
from .llm_pb2 import GenerateRequestBody
from .llm_pb2 import GenerateResponse
from .llm_pb2 import GenerateResponseHead
from .llm_pb2 import GenerateResponseHeadBody
from .llm_pb2 import GenerateResponseBody
from .llm_pb2 import GenerateResponseTail
from .llm_pb2 import GenerateResponseTailBody
from .llm_pb2 import TextPrompt
from .llm_pb2 import ImagePrompt
from .llm_pb2 import ImageResult
from .llm_pb2 import EditRequest
from .llm_pb2 import EditResponse
from .llm_pb2 import TranslateRequest
from .llm_pb2 import TranslateResponse
from .llm_pb2 import ConvertRequest
from .llm_pb2 import ConvertResponse
from .llm_pb2 import Choice
from .llm_pb2 import SpeechRequest
from .llm_pb2 import SpeechResponse
from .llm_pb2 import MessageRoleEnum
from .llm_pb2 import ContentTypeEnum
from .llm_pb2_grpc import LlmServicer
from .llm_pb2_grpc import LlmStub
from .llm_pb2_grpc import add_LlmServicer_to_server
from .llm_pb2_grpc import Llm
from .provider_pb2 import ProviderDescriptionsRequest
from .provider_pb2 import ProviderDescriptionsResponse
from .provider_pb2 import ProviderDescriptionsResponseBody
from .provider_pb2 import ProviderModelsRequest
from .provider_pb2 import ProviderModelsRequestBody
from .provider_pb2 import ProviderModelsResponse
from .provider_pb2 import ProviderModelsResponseBody
from .provider_pb2 import DeleteProviderRequest
from .provider_pb2 import DeleteProviderRequestBody
from .provider_pb2 import DeleteProviderResponse
from .provider_pb2 import DeleteProviderResponseBody
from .provider_pb2 import SearchProviderRequest
from .provider_pb2 import SearchProviderRequestBody
from .provider_pb2 import SearchProviderResponse
from .provider_pb2 import SearchProviderResponseBody
from .provider_pb2 import AddProviderRequest
from .provider_pb2 import AddProviderRequestBody
from .provider_pb2 import AddProviderResponse
from .provider_pb2 import AddProviderResponseBody
from .provider_pb2 import ProviderDetailRequest
from .provider_pb2 import ProviderDetailRequestBody
from .provider_pb2 import ProviderDetailResponse
from .provider_pb2 import ProviderDetailResponseBody
from .provider_pb2 import ProviderDetail
from .provider_pb2 import ProviderDescription
from .provider_pb2 import SearchProviderCondition
from .provider_pb2 import ProviderMetadata
from .provider_pb2 import ModelMetadata
from .provider_pb2 import ProviderState
from .provider_pb2 import ModelTypeEnum
from .provider_pb2 import ModelFeatureEnum
from .provider_pb2 import ProviderCodeEnum
from .provider_pb2 import ProviderStatusEnum
from .provider_pb2 import QuotaTypeEnum
from .provider_pb2_grpc import ProviderServicer
from .provider_pb2_grpc import ProviderStub
from .provider_pb2_grpc import add_ProviderServicer_to_server
from .provider_pb2_grpc import Provider



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/web3/web3.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/web3/web3.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/web3/web3.proto\x12\x0fyeying.api.web3"\xf0\x03\n\x08Identity\x12\x33\n\x08metadata\x18\x01 \x01(\x0b\x32!.yeying.api.web3.IdentityMetadata\x12\x14\n\x0c\x62lockAddress\x18\x02 \x01(\t\x12\x37\n\x0esecurityConfig\x18\x03 \x01(\x0b\x32\x1f.yeying.api.web3.SecurityConfig\x12+\n\x08registry\x18\x04 \x01(\x0b\x32\x19.yeying.api.web3.Registry\x12\x11\n\tsignature\x18\x05 \x01(\t\x12\x41\n\x0epersonalExtend\x18\x06 \x01(\x0b\x32\'.yeying.api.web3.IdentityPersonalExtendH\x00\x12?\n\rserviceExtend\x18\x07 \x01(\x0b\x32&.yeying.api.web3.IdentityServiceExtendH\x00\x12I\n\x12organizationExtend\x18\x08 \x01(\x0b\x32+.yeying.api.web3.IdentityOrganizationExtendH\x00\x12G\n\x11\x61pplicationExtend\x18\t \x01(\x0b\x32*.yeying.api.web3.IdentityApplicationExtendH\x00\x42\x08\n\x06\x65xtend"\x19\n\x08Registry\x12\r\n\x05nodes\x18\x01 \x03(\t"\x8e\x02\n\x10IdentityMetadata\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x31\n\x07network\x18\x02 \x01(\x0e\x32 .yeying.api.web3.NetworkTypeEnum\x12\x0b\n\x03\x64id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12/\n\x04\x63ode\x18\x08 \x01(\x0e\x32!.yeying.api.web3.IdentityCodeEnum\x12\x0e\n\x06\x61vatar\x18\t \x01(\t\x12\x11\n\tcreatedAt\x18\n \x01(\t\x12\x11\n\tupdatedAt\x18\x0b \x01(\t"\x87\x01\n\x0c\x42lockAddress\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x12\n\nprivateKey\x18\x03 \x01(\t\x12\x11\n\tpublicKey\x18\x04 \x01(\t\x12+\n\x08mnemonic\x18\x05 \x01(\x0b\x32\x19.yeying.api.web3.Mnemonic"J\n\x08Mnemonic\x12\x0e\n\x06phrase\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t"d\n\x15IdentityServiceExtend\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x10\n\x08\x61piCodes\x18\x02 \x01(\t\x12\r\n\x05proxy\x18\x03 \x01(\t\x12\x0c\n\x04grpc\x18\x04 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x05 \x01(\t"K\n\x1aIdentityOrganizationExtend\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x03 \x01(\t"J\n\x16IdentityPersonalExtend\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x11\n\ttelephone\x18\x02 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x03 \x01(\t"o\n\x19IdentityApplicationExtend\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x14\n\x0cserviceCodes\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x05 \x01(\t"G\n\x0eSecurityConfig\x12\x35\n\talgorithm\x18\x01 \x01(\x0b\x32".yeying.api.web3.SecurityAlgorithm"-\n\x11SecurityAlgorithm\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02iv\x18\x02 \x01(\t*\xbc\x01\n\x10IdentityCodeEnum\x12\x19\n\x15IDENTITY_CODE_UNKNOWN\x10\x00\x12\x1a\n\x16IDENTITY_CODE_PERSONAL\x10\x01\x12\x1e\n\x1aIDENTITY_CODE_ORGANIZATION\x10\x02\x12\x19\n\x15IDENTITY_CODE_SERVICE\x10\x03\x12\x1d\n\x19IDENTITY_CODE_APPLICATION\x10\x04\x12\x17\n\x13IDENTITY_CODE_ASSET\x10\x05*E\n\x0fNetworkTypeEnum\x12\x18\n\x14NETWORK_TYPE_UNKNOWN\x10\x00\x12\x18\n\x13NETWORK_TYPE_YEYING\x10\xe4\x0f\x42\x11Z\x0fyeying/api/web3b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.web3.web3_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/web3"
    _globals["_IDENTITYCODEENUM"]._serialized_start = 1549
    _globals["_IDENTITYCODEENUM"]._serialized_end = 1737
    _globals["_NETWORKTYPEENUM"]._serialized_start = 1739
    _globals["_NETWORKTYPEENUM"]._serialized_end = 1808
    _globals["_IDENTITY"]._serialized_start = 48
    _globals["_IDENTITY"]._serialized_end = 544
    _globals["_REGISTRY"]._serialized_start = 546
    _globals["_REGISTRY"]._serialized_end = 571
    _globals["_IDENTITYMETADATA"]._serialized_start = 574
    _globals["_IDENTITYMETADATA"]._serialized_end = 844
    _globals["_BLOCKADDRESS"]._serialized_start = 847
    _globals["_BLOCKADDRESS"]._serialized_end = 982
    _globals["_MNEMONIC"]._serialized_start = 984
    _globals["_MNEMONIC"]._serialized_end = 1058
    _globals["_IDENTITYSERVICEEXTEND"]._serialized_start = 1060
    _globals["_IDENTITYSERVICEEXTEND"]._serialized_end = 1160
    _globals["_IDENTITYORGANIZATIONEXTEND"]._serialized_start = 1162
    _globals["_IDENTITYORGANIZATIONEXTEND"]._serialized_end = 1237
    _globals["_IDENTITYPERSONALEXTEND"]._serialized_start = 1239
    _globals["_IDENTITYPERSONALEXTEND"]._serialized_end = 1313
    _globals["_IDENTITYAPPLICATIONEXTEND"]._serialized_start = 1315
    _globals["_IDENTITYAPPLICATIONEXTEND"]._serialized_end = 1426
    _globals["_SECURITYCONFIG"]._serialized_start = 1428
    _globals["_SECURITYCONFIG"]._serialized_end = 1499
    _globals["_SECURITYALGORITHM"]._serialized_start = 1501
    _globals["_SECURITYALGORITHM"]._serialized_end = 1546
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/message.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/message.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/apps/zuoyepigai/message.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x88\x01\n\x12MessageListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.MessageListRequestBody"w\n\x16MessageListRequestBody\x12.\n\tpageIndex\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"\x8a\x01\n\x13MessageListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.MessageListResponseBody"\x96\x01\n\x17MessageListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04list\x18\x02 \x03(\x0b\x32+.yeying.api.apps.zuoyepigai.MessageMetadata\x12\r\n\x05total\x18\x03 \x01(\x04"|\n\x0c\x43ountRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.apps.zuoyepigai.CountRequestBody"\x12\n\x10\x43ountRequestBody"~\n\rCountResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.CountResponseBody"\x7f\n\x11\x43ountResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x03(\x0b\x32).yeying.api.apps.zuoyepigai.CountMetadata",\n\rCountMetadata\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\r\n\x05\x63ount\x18\x02 \x01(\x05"~\n\rListByRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.ListByRequestBody"1\n\x11ListByRequestBody\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05"\x80\x01\n\x0eListByResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12<\n\x04\x62ody\x18\x02 \x01(\x0b\x32..yeying.api.apps.zuoyepigai.ListByResponseBody"\x91\x01\n\x12ListByResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x03(\x0b\x32+.yeying.api.apps.zuoyepigai.MessageMetadata\x12\r\n\x05\x63ount\x18\x03 \x01(\x05"\x86\x01\n\x11MarkAsReadRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.MarkAsReadRequestBody"$\n\x15MarkAsReadRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x88\x01\n\x12MarkAsReadResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.MarkAsReadResponseBody"K\n\x16MarkAsReadResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xa6\x03\n\x07Message\x12i\n\x04List\x12..yeying.api.apps.zuoyepigai.MessageListRequest\x1a/.yeying.api.apps.zuoyepigai.MessageListResponse"\x00\x12^\n\x05\x43ount\x12(.yeying.api.apps.zuoyepigai.CountRequest\x1a).yeying.api.apps.zuoyepigai.CountResponse"\x00\x12\x61\n\x06ListBy\x12).yeying.api.apps.zuoyepigai.ListByRequest\x1a*.yeying.api.apps.zuoyepigai.ListByResponse"\x00\x12m\n\nMarkAsRead\x12-.yeying.api.apps.zuoyepigai.MarkAsReadRequest\x1a..yeying.api.apps.zuoyepigai.MarkAsReadResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.message_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_MESSAGELISTREQUEST"]._serialized_start = 177
    _globals["_MESSAGELISTREQUEST"]._serialized_end = 313
    _globals["_MESSAGELISTREQUESTBODY"]._serialized_start = 315
    _globals["_MESSAGELISTREQUESTBODY"]._serialized_end = 434
    _globals["_MESSAGELISTRESPONSE"]._serialized_start = 437
    _globals["_MESSAGELISTRESPONSE"]._serialized_end = 575
    _globals["_MESSAGELISTRESPONSEBODY"]._serialized_start = 578
    _globals["_MESSAGELISTRESPONSEBODY"]._serialized_end = 728
    _globals["_COUNTREQUEST"]._serialized_start = 730
    _globals["_COUNTREQUEST"]._serialized_end = 854
    _globals["_COUNTREQUESTBODY"]._serialized_start = 856
    _globals["_COUNTREQUESTBODY"]._serialized_end = 874
    _globals["_COUNTRESPONSE"]._serialized_start = 876
    _globals["_COUNTRESPONSE"]._serialized_end = 1002
    _globals["_COUNTRESPONSEBODY"]._serialized_start = 1004
    _globals["_COUNTRESPONSEBODY"]._serialized_end = 1131
    _globals["_COUNTMETADATA"]._serialized_start = 1133
    _globals["_COUNTMETADATA"]._serialized_end = 1177
    _globals["_LISTBYREQUEST"]._serialized_start = 1179
    _globals["_LISTBYREQUEST"]._serialized_end = 1305
    _globals["_LISTBYREQUESTBODY"]._serialized_start = 1307
    _globals["_LISTBYREQUESTBODY"]._serialized_end = 1356
    _globals["_LISTBYRESPONSE"]._serialized_start = 1359
    _globals["_LISTBYRESPONSE"]._serialized_end = 1487
    _globals["_LISTBYRESPONSEBODY"]._serialized_start = 1490
    _globals["_LISTBYRESPONSEBODY"]._serialized_end = 1635
    _globals["_MARKASREADREQUEST"]._serialized_start = 1638
    _globals["_MARKASREADREQUEST"]._serialized_end = 1772
    _globals["_MARKASREADREQUESTBODY"]._serialized_start = 1774
    _globals["_MARKASREADREQUESTBODY"]._serialized_end = 1810
    _globals["_MARKASREADRESPONSE"]._serialized_start = 1813
    _globals["_MARKASREADRESPONSE"]._serialized_end = 1949
    _globals["_MARKASREADRESPONSEBODY"]._serialized_start = 1951
    _globals["_MARKASREADRESPONSEBODY"]._serialized_end = 2026
    _globals["_MESSAGE"]._serialized_start = 2029
    _globals["_MESSAGE"]._serialized_end = 2451
# @@protoc_insertion_point(module_scope)



import codecs
from yeying.client.utils.signature_utils import verify


def encode_key(key):
    return codecs.decode(key[2:] if key.startswith("0x") else key, "hex")


def convert_did_to_publickey(did):
    public_key = did.split(":")[-1]
    return public_key[2:] if public_key.startswith("0x") else public_key


def verify_identity(identity):
    signature = identity.signature
    try:
        identity.signature = ""
        public_key = encode_key(convert_did_to_publickey(identity.metadata.did))
        return verify(public_key=public_key, data=identity.SerializeToString(), signature=signature)
    finally:
        identity.signature = signature



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/user/user.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/user/user.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/user/user.proto\x12\x0fyeying.api.user\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fyeying/api/common/message.proto"\x7f\n\x13UpdateStatusRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.user.UpdateStatusRequestBody"W\n\x17UpdateStatusRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.yeying.api.user.UserStatusEnum"\x81\x01\n\x14UpdateStatusResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.user.UpdateStatusResponseBody"M\n\x18UpdateStatusResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"w\n\x0fUserListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.user.UserListRequestBody"t\n\x13UserListRequestBody\x12.\n\tpageIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"y\n\x10UserListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.user.UserListResponseBody"\x83\x01\n\x14UserListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12)\n\x04list\x18\x02 \x03(\x0b\x32\x1b.yeying.api.user.UserDetail\x12\r\n\x05total\x18\x03 \x01(\x04"\x94\x01\n\x0cUserMetadata\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\t\x12\x11\n\tupdatedAt\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\t\x12\x11\n\ttelephone\x18\x07 \x01(\t\x12\r\n\x05\x65mail\x18\x08 \x01(\t"\xbe\x01\n\tUserState\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12+\n\x04role\x18\x03 \x01(\x0e\x32\x1d.yeying.api.user.UserRoleEnum\x12/\n\x06status\x18\x04 \x01(\x0e\x32\x1f.yeying.api.user.UserStatusEnum\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tupdatedAt\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t"u\n\x0e\x41\x64\x64UserRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.user.AddUserRequestBody"A\n\x12\x41\x64\x64UserRequestBody\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"w\n\x0f\x41\x64\x64UserResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.user.AddUserResponseBody"u\n\x13\x41\x64\x64UserResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12+\n\x04user\x18\x02 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"{\n\x11UpdateUserRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.user.UpdateUserRequestBody"D\n\x15UpdateUserRequestBody\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"}\n\x12UpdateUserResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.user.UpdateUserResponseBody"x\n\x16UpdateUserResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12+\n\x04user\x18\x02 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"E\n\x11\x44\x65leteUserRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"}\n\x12\x44\x65leteUserResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.user.DeleteUserResponseBody"K\n\x16\x44\x65leteUserResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"E\n\x11UserDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"}\n\x12UserDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.user.UserDetailResponseBody"x\n\x16UserDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12+\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1b.yeying.api.user.UserDetail"d\n\nUserDetail\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata\x12)\n\x05state\x18\x02 \x01(\x0b\x32\x1a.yeying.api.user.UserState*\x9f\x02\n\x0eUserStatusEnum\x12\x17\n\x13USER_STATUS_UNKNOWN\x10\x00\x12\x16\n\x12USER_STATUS_ACTIVE\x10\x01\x12\x17\n\x13USER_STATUS_OFFLINE\x10\x02\x12\x17\n\x13USER_STATUS_DISABLE\x10\x03\x12\x14\n\x10USER_STATUS_LOCK\x10\x04\x12\x1a\n\x16USER_STATUS_UNVERIFIED\x10\x05\x12\x17\n\x13USER_STATUS_DELETED\x10\x06\x12\x17\n\x13USER_STATUS_DORMANT\x10\x07\x12\x16\n\x12USER_STATUS_FREEZE\x10\x08\x12\x15\n\x11USER_STATUS_AUDIT\x10\t\x12\x17\n\x13USER_STATUS_REFUSED\x10\n*P\n\x0cUserRoleEnum\x12\x15\n\x11USER_ROLE_UNKNOWN\x10\x00\x12\x13\n\x0fUSER_ROLE_OWNER\x10\x01\x12\x14\n\x10USER_ROLE_NORMAL\x10\x02\x32\xff\x03\n\x04User\x12J\n\x03\x41\x64\x64\x12\x1f.yeying.api.user.AddUserRequest\x1a .yeying.api.user.AddUserResponse"\x00\x12S\n\x06\x44\x65tail\x12".yeying.api.user.UserDetailRequest\x1a#.yeying.api.user.UserDetailResponse"\x00\x12M\n\x04List\x12 .yeying.api.user.UserListRequest\x1a!.yeying.api.user.UserListResponse"\x00\x12S\n\x06\x44\x65lete\x12".yeying.api.user.DeleteUserRequest\x1a#.yeying.api.user.DeleteUserResponse"\x00\x12S\n\x06Update\x12".yeying.api.user.UpdateUserRequest\x1a#.yeying.api.user.UpdateUserResponse"\x00\x12]\n\x0cUpdateStatus\x12$.yeying.api.user.UpdateStatusRequest\x1a%.yeying.api.user.UpdateStatusResponse"\x00\x42\x11Z\x0fyeying/api/userb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.user.user_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/user"
    _globals["_USERSTATUSENUM"]._serialized_start = 2949
    _globals["_USERSTATUSENUM"]._serialized_end = 3236
    _globals["_USERROLEENUM"]._serialized_start = 3238
    _globals["_USERROLEENUM"]._serialized_end = 3318
    _globals["_UPDATESTATUSREQUEST"]._serialized_start = 112
    _globals["_UPDATESTATUSREQUEST"]._serialized_end = 239
    _globals["_UPDATESTATUSREQUESTBODY"]._serialized_start = 241
    _globals["_UPDATESTATUSREQUESTBODY"]._serialized_end = 328
    _globals["_UPDATESTATUSRESPONSE"]._serialized_start = 331
    _globals["_UPDATESTATUSRESPONSE"]._serialized_end = 460
    _globals["_UPDATESTATUSRESPONSEBODY"]._serialized_start = 462
    _globals["_UPDATESTATUSRESPONSEBODY"]._serialized_end = 539
    _globals["_USERLISTREQUEST"]._serialized_start = 541
    _globals["_USERLISTREQUEST"]._serialized_end = 660
    _globals["_USERLISTREQUESTBODY"]._serialized_start = 662
    _globals["_USERLISTREQUESTBODY"]._serialized_end = 778
    _globals["_USERLISTRESPONSE"]._serialized_start = 780
    _globals["_USERLISTRESPONSE"]._serialized_end = 901
    _globals["_USERLISTRESPONSEBODY"]._serialized_start = 904
    _globals["_USERLISTRESPONSEBODY"]._serialized_end = 1035
    _globals["_USERMETADATA"]._serialized_start = 1038
    _globals["_USERMETADATA"]._serialized_end = 1186
    _globals["_USERSTATE"]._serialized_start = 1189
    _globals["_USERSTATE"]._serialized_end = 1379
    _globals["_ADDUSERREQUEST"]._serialized_start = 1381
    _globals["_ADDUSERREQUEST"]._serialized_end = 1498
    _globals["_ADDUSERREQUESTBODY"]._serialized_start = 1500
    _globals["_ADDUSERREQUESTBODY"]._serialized_end = 1565
    _globals["_ADDUSERRESPONSE"]._serialized_start = 1567
    _globals["_ADDUSERRESPONSE"]._serialized_end = 1686
    _globals["_ADDUSERRESPONSEBODY"]._serialized_start = 1688
    _globals["_ADDUSERRESPONSEBODY"]._serialized_end = 1805
    _globals["_UPDATEUSERREQUEST"]._serialized_start = 1807
    _globals["_UPDATEUSERREQUEST"]._serialized_end = 1930
    _globals["_UPDATEUSERREQUESTBODY"]._serialized_start = 1932
    _globals["_UPDATEUSERREQUESTBODY"]._serialized_end = 2000
    _globals["_UPDATEUSERRESPONSE"]._serialized_start = 2002
    _globals["_UPDATEUSERRESPONSE"]._serialized_end = 2127
    _globals["_UPDATEUSERRESPONSEBODY"]._serialized_start = 2129
    _globals["_UPDATEUSERRESPONSEBODY"]._serialized_end = 2249
    _globals["_DELETEUSERREQUEST"]._serialized_start = 2251
    _globals["_DELETEUSERREQUEST"]._serialized_end = 2320
    _globals["_DELETEUSERRESPONSE"]._serialized_start = 2322
    _globals["_DELETEUSERRESPONSE"]._serialized_end = 2447
    _globals["_DELETEUSERRESPONSEBODY"]._serialized_start = 2449
    _globals["_DELETEUSERRESPONSEBODY"]._serialized_end = 2524
    _globals["_USERDETAILREQUEST"]._serialized_start = 2526
    _globals["_USERDETAILREQUEST"]._serialized_end = 2595
    _globals["_USERDETAILRESPONSE"]._serialized_start = 2597
    _globals["_USERDETAILRESPONSE"]._serialized_end = 2722
    _globals["_USERDETAILRESPONSEBODY"]._serialized_start = 2724
    _globals["_USERDETAILRESPONSEBODY"]._serialized_end = 2844
    _globals["_USERDETAIL"]._serialized_start = 2846
    _globals["_USERDETAIL"]._serialized_end = 2946
    _globals["_USER"]._serialized_start = 3321
    _globals["_USER"]._serialized_end = 3832
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class ModelTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MODEL_TYPE_UNKNOWN: _ClassVar[ModelTypeEnum]
    MODEL_TYPE_LLM: _ClassVar[ModelTypeEnum]
    MODEL_TYPE_TEXT_EMBEDDING: _ClassVar[ModelTypeEnum]
    MODEL_TYPE_RERANK: _ClassVar[ModelTypeEnum]
    MODEL_TYPE_SPEECH2TEXT: _ClassVar[ModelTypeEnum]
    MODEL_TYPE_TTS: _ClassVar[ModelTypeEnum]
    MODEL_TYPE_MODERATION: _ClassVar[ModelTypeEnum]
    MODEL_TYPE_TEXT2IMAGE: _ClassVar[ModelTypeEnum]

class ModelFeatureEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MODEL_FEATURE_AGENT_THOUGHT: _ClassVar[ModelFeatureEnum]
    MODEL_FEATURE_VISION: _ClassVar[ModelFeatureEnum]
    MODEL_FEATURE_TOOL_CALL: _ClassVar[ModelFeatureEnum]
    MODEL_FEATURE_MULTI_TOOL_CALL: _ClassVar[ModelFeatureEnum]
    MODEL_FEATURE_STREAM_TOOL_CALL: _ClassVar[ModelFeatureEnum]
    MODEL_FEATURE_DOCUMENT: _ClassVar[ModelFeatureEnum]
    MODEL_FEATURE_VIDEO: _ClassVar[ModelFeatureEnum]
    MODEL_FEATURE_AUDIO: _ClassVar[ModelFeatureEnum]

class ProviderCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROVIDER_CODE_UNKNOWN: _ClassVar[ProviderCodeEnum]
    PROVIDER_CODE_OPENAI: _ClassVar[ProviderCodeEnum]
    PROVIDER_CODE_TONGYI: _ClassVar[ProviderCodeEnum]
    PROVIDER_CODE_ZHIPUAI: _ClassVar[ProviderCodeEnum]
    PROVIDER_CODE_GROK: _ClassVar[ProviderCodeEnum]
    PROVIDER_CODE_DEEPSEEK: _ClassVar[ProviderCodeEnum]

class ProviderStatusEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROVIDER_STATUS_UNKNOWN: _ClassVar[ProviderStatusEnum]
    PROVIDER_STATUS_UNAVAILABLE: _ClassVar[ProviderStatusEnum]
    PROVIDER_STATUS_AVAILABLE: _ClassVar[ProviderStatusEnum]

class QuotaTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    QUOTA_TYPE_UNKNOWN: _ClassVar[QuotaTypeEnum]
    QUOTA_TYPE_PAID: _ClassVar[QuotaTypeEnum]
    QUOTA_TYPE_FREE: _ClassVar[QuotaTypeEnum]
    QUOTA_TYPE_TRIAL: _ClassVar[QuotaTypeEnum]

MODEL_TYPE_UNKNOWN: ModelTypeEnum
MODEL_TYPE_LLM: ModelTypeEnum
MODEL_TYPE_TEXT_EMBEDDING: ModelTypeEnum
MODEL_TYPE_RERANK: ModelTypeEnum
MODEL_TYPE_SPEECH2TEXT: ModelTypeEnum
MODEL_TYPE_TTS: ModelTypeEnum
MODEL_TYPE_MODERATION: ModelTypeEnum
MODEL_TYPE_TEXT2IMAGE: ModelTypeEnum
MODEL_FEATURE_AGENT_THOUGHT: ModelFeatureEnum
MODEL_FEATURE_VISION: ModelFeatureEnum
MODEL_FEATURE_TOOL_CALL: ModelFeatureEnum
MODEL_FEATURE_MULTI_TOOL_CALL: ModelFeatureEnum
MODEL_FEATURE_STREAM_TOOL_CALL: ModelFeatureEnum
MODEL_FEATURE_DOCUMENT: ModelFeatureEnum
MODEL_FEATURE_VIDEO: ModelFeatureEnum
MODEL_FEATURE_AUDIO: ModelFeatureEnum
PROVIDER_CODE_UNKNOWN: ProviderCodeEnum
PROVIDER_CODE_OPENAI: ProviderCodeEnum
PROVIDER_CODE_TONGYI: ProviderCodeEnum
PROVIDER_CODE_ZHIPUAI: ProviderCodeEnum
PROVIDER_CODE_GROK: ProviderCodeEnum
PROVIDER_CODE_DEEPSEEK: ProviderCodeEnum
PROVIDER_STATUS_UNKNOWN: ProviderStatusEnum
PROVIDER_STATUS_UNAVAILABLE: ProviderStatusEnum
PROVIDER_STATUS_AVAILABLE: ProviderStatusEnum
QUOTA_TYPE_UNKNOWN: QuotaTypeEnum
QUOTA_TYPE_PAID: QuotaTypeEnum
QUOTA_TYPE_FREE: QuotaTypeEnum
QUOTA_TYPE_TRIAL: QuotaTypeEnum

class ProviderDescriptionsRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class ProviderDescriptionsResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ProviderDescriptionsResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ProviderDescriptionsResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ProviderDescriptionsResponseBody(_message.Message):
    __slots__ = ("status", "descriptions")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    descriptions: _containers.RepeatedCompositeFieldContainer[ProviderDescription]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        descriptions: _Optional[_Iterable[_Union[ProviderDescription, _Mapping]]] = ...,
    ) -> None: ...

class ProviderModelsRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ProviderModelsRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ProviderModelsRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ProviderModelsRequestBody(_message.Message):
    __slots__ = ("code", "modelType")
    CODE_FIELD_NUMBER: _ClassVar[int]
    MODELTYPE_FIELD_NUMBER: _ClassVar[int]
    code: ProviderCodeEnum
    modelType: ModelTypeEnum
    def __init__(
        self,
        code: _Optional[_Union[ProviderCodeEnum, str]] = ...,
        modelType: _Optional[_Union[ModelTypeEnum, str]] = ...,
    ) -> None: ...

class ProviderModelsResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ProviderModelsResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ProviderModelsResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ProviderModelsResponseBody(_message.Message):
    __slots__ = ("status", "models")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MODELS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    models: _containers.RepeatedCompositeFieldContainer[ModelMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        models: _Optional[_Iterable[_Union[ModelMetadata, _Mapping]]] = ...,
    ) -> None: ...

class DeleteProviderRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteProviderRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteProviderRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteProviderRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DeleteProviderResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteProviderResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteProviderResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteProviderResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class SearchProviderRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchProviderRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchProviderRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SearchProviderRequestBody(_message.Message):
    __slots__ = ("page", "condition")
    PAGE_FIELD_NUMBER: _ClassVar[int]
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    page: _message_pb2.RequestPage
    condition: SearchProviderCondition
    def __init__(
        self,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
        condition: _Optional[_Union[SearchProviderCondition, _Mapping]] = ...,
    ) -> None: ...

class SearchProviderResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchProviderResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchProviderResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SearchProviderResponseBody(_message.Message):
    __slots__ = ("status", "providers")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    providers: _containers.RepeatedCompositeFieldContainer[ProviderMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        providers: _Optional[_Iterable[_Union[ProviderMetadata, _Mapping]]] = ...,
    ) -> None: ...

class AddProviderRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddProviderRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddProviderRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AddProviderRequestBody(_message.Message):
    __slots__ = ("provider",)
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    provider: ProviderMetadata
    def __init__(self, provider: _Optional[_Union[ProviderMetadata, _Mapping]] = ...) -> None: ...

class AddProviderResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddProviderResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddProviderResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AddProviderResponseBody(_message.Message):
    __slots__ = ("status", "provider")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    provider: ProviderMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        provider: _Optional[_Union[ProviderMetadata, _Mapping]] = ...,
    ) -> None: ...

class ProviderDetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ProviderDetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ProviderDetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ProviderDetailRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class ProviderDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ProviderDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ProviderDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ProviderDetailResponseBody(_message.Message):
    __slots__ = ("status", "detail")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    detail: ProviderDetail
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        detail: _Optional[_Union[ProviderDetail, _Mapping]] = ...,
    ) -> None: ...

class ProviderDetail(_message.Message):
    __slots__ = ("provider", "state")
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    provider: ProviderMetadata
    state: ProviderState
    def __init__(
        self,
        provider: _Optional[_Union[ProviderMetadata, _Mapping]] = ...,
        state: _Optional[_Union[ProviderState, _Mapping]] = ...,
    ) -> None: ...

class ProviderDescription(_message.Message):
    __slots__ = ("code", "name", "description", "supportedModelTypes", "avatar")
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SUPPORTEDMODELTYPES_FIELD_NUMBER: _ClassVar[int]
    AVATAR_FIELD_NUMBER: _ClassVar[int]
    code: ProviderCodeEnum
    name: str
    description: str
    supportedModelTypes: _containers.RepeatedScalarFieldContainer[ModelTypeEnum]
    avatar: str
    def __init__(
        self,
        code: _Optional[_Union[ProviderCodeEnum, str]] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        supportedModelTypes: _Optional[_Iterable[_Union[ModelTypeEnum, str]]] = ...,
        avatar: _Optional[str] = ...,
    ) -> None: ...

class SearchProviderCondition(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: ProviderCodeEnum
    def __init__(self, code: _Optional[_Union[ProviderCodeEnum, str]] = ...) -> None: ...

class ProviderMetadata(_message.Message):
    __slots__ = (
        "uid",
        "owner",
        "name",
        "code",
        "config",
        "quotaType",
        "quotaLimit",
        "createdAt",
        "updatedAt",
        "signature",
    )
    UID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    QUOTATYPE_FIELD_NUMBER: _ClassVar[int]
    QUOTALIMIT_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    uid: str
    owner: str
    name: str
    code: ProviderCodeEnum
    config: str
    quotaType: QuotaTypeEnum
    quotaLimit: int
    createdAt: str
    updatedAt: str
    signature: str
    def __init__(
        self,
        uid: _Optional[str] = ...,
        owner: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[_Union[ProviderCodeEnum, str]] = ...,
        config: _Optional[str] = ...,
        quotaType: _Optional[_Union[QuotaTypeEnum, str]] = ...,
        quotaLimit: _Optional[int] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...

class ModelMetadata(_message.Message):
    __slots__ = ("providerCode", "type", "name", "features")
    PROVIDERCODE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    providerCode: ProviderCodeEnum
    type: ModelTypeEnum
    name: str
    features: _containers.RepeatedScalarFieldContainer[ModelFeatureEnum]
    def __init__(
        self,
        providerCode: _Optional[_Union[ProviderCodeEnum, str]] = ...,
        type: _Optional[_Union[ModelTypeEnum, str]] = ...,
        name: _Optional[str] = ...,
        features: _Optional[_Iterable[_Union[ModelFeatureEnum, str]]] = ...,
    ) -> None: ...

class ProviderState(_message.Message):
    __slots__ = ("serviceDid", "uid", "status", "quotaUsed", "createdAt", "updatedAt", "signature")
    SERVICEDID_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    QUOTAUSED_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    serviceDid: str
    uid: str
    status: ProviderStatusEnum
    quotaUsed: int
    createdAt: str
    updatedAt: str
    signature: str
    def __init__(
        self,
        serviceDid: _Optional[str] = ...,
        uid: _Optional[str] = ...,
        status: _Optional[_Union[ProviderStatusEnum, str]] = ...,
        quotaUsed: _Optional[int] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.asset import asset_pb2 as yeying_dot_api_dot_asset_dot_asset__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/asset/asset_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class AssetStub(object):
    """*

    整个资产仓库基于分布式数字身份和资产内容哈希驱动，并能够在不同资产仓库间转移

    开放的分散式仓库网络的接口设计，参考了现实世界中的仓库，逻辑如下：
    1、数字资产有两个标识，一个是数字资产的身份标识，可以是分布式数字身份，也可以是用户自定义的身份ID，另一个是数字资产内容的哈希值；
    2、数字资产入库，发送到指定存储网络中的节点，可以指定副本数量，一方面保证内容不会因为单个节点故障而丢失，另外也保证内容的可访问性；
    3、存储复用，如果两份资产哈希值一样，分两种情况来看，如果资产的所有者一样，则仓库会主动告知身份持有者存在重复，如果资产的所有者不同，会增加引用；
    4、授权数字资产，所有者和使用者立交易关系，确保使用者根据指定的策略访问数据，仓库会统计数字资产的使用情况，比如统计内容取（浏览）的次数评估内容热度
    ，或者统计内容存的次数（收藏）评估内容质量，目的是更好的分配存储资源；

    仓库使用场景：
    1、创作场景，知识产权证明
    2、代码包分发场景，比如软件包，模型包等
    3、数字资产，类似nft等

    资产定位逻辑：

    采用三元组唯一定位，(用户身份、命名空间、哈希值)
    命名空间的定位逻辑：某个用户下面是唯一的，命名空间所有者，可以指定多个参与者，用于存储完成某项工作生成资产数据，这些资产数据属于命名空间所有者
    资产的定位逻辑：每个命名空间是隔离的，同一个所有者，同一个命名空间，资产哈希值必须唯一
    资产块的定位逻辑：每个命名空间是隔离的，用一个所有者，同一个命名空间，资产块是唯一的，资产块维持一个引用计数，其逻辑如下：
    - 当有一个新资产放入命名空间，则引用计数加1；
    - 当有一个老资产移出命名空间，则引用计数减1；
    当某个资产块的引用计数为0，表示没有和资产仓库服务签约，只是临时存储，通常分块上传完成以后就会立即签约，但是考虑委托第三方服务生成的数据直接放到命名
    空间，第三方服务没有命名空间所有者的私钥，无法和资产仓库完成签约，只能先上传，事后由命名空间所有者完成签名；

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Search = channel.unary_unary(
            "/yeying.api.asset.Asset/Search",
            request_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.SearchAssetRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.SearchAssetResponse.FromString,
            _registered_method=True,
        )
        self.Sign = channel.unary_unary(
            "/yeying.api.asset.Asset/Sign",
            request_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.SignAssetRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.SignAssetResponse.FromString,
            _registered_method=True,
        )
        self.Update = channel.unary_unary(
            "/yeying.api.asset.Asset/Update",
            request_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.UpdateAssetRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.UpdateAssetResponse.FromString,
            _registered_method=True,
        )
        self.Detail = channel.unary_unary(
            "/yeying.api.asset.Asset/Detail",
            request_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.AssetDetailRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.AssetDetailResponse.FromString,
            _registered_method=True,
        )
        self.Delete = channel.unary_unary(
            "/yeying.api.asset.Asset/Delete",
            request_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.DeleteAssetRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.DeleteAssetResponse.FromString,
            _registered_method=True,
        )


class AssetServicer(object):
    """*

    整个资产仓库基于分布式数字身份和资产内容哈希驱动，并能够在不同资产仓库间转移

    开放的分散式仓库网络的接口设计，参考了现实世界中的仓库，逻辑如下：
    1、数字资产有两个标识，一个是数字资产的身份标识，可以是分布式数字身份，也可以是用户自定义的身份ID，另一个是数字资产内容的哈希值；
    2、数字资产入库，发送到指定存储网络中的节点，可以指定副本数量，一方面保证内容不会因为单个节点故障而丢失，另外也保证内容的可访问性；
    3、存储复用，如果两份资产哈希值一样，分两种情况来看，如果资产的所有者一样，则仓库会主动告知身份持有者存在重复，如果资产的所有者不同，会增加引用；
    4、授权数字资产，所有者和使用者立交易关系，确保使用者根据指定的策略访问数据，仓库会统计数字资产的使用情况，比如统计内容取（浏览）的次数评估内容热度
    ，或者统计内容存的次数（收藏）评估内容质量，目的是更好的分配存储资源；

    仓库使用场景：
    1、创作场景，知识产权证明
    2、代码包分发场景，比如软件包，模型包等
    3、数字资产，类似nft等

    资产定位逻辑：

    采用三元组唯一定位，(用户身份、命名空间、哈希值)
    命名空间的定位逻辑：某个用户下面是唯一的，命名空间所有者，可以指定多个参与者，用于存储完成某项工作生成资产数据，这些资产数据属于命名空间所有者
    资产的定位逻辑：每个命名空间是隔离的，同一个所有者，同一个命名空间，资产哈希值必须唯一
    资产块的定位逻辑：每个命名空间是隔离的，用一个所有者，同一个命名空间，资产块是唯一的，资产块维持一个引用计数，其逻辑如下：
    - 当有一个新资产放入命名空间，则引用计数加1；
    - 当有一个老资产移出命名空间，则引用计数减1；
    当某个资产块的引用计数为0，表示没有和资产仓库服务签约，只是临时存储，通常分块上传完成以后就会立即签约，但是考虑委托第三方服务生成的数据直接放到命名
    空间，第三方服务没有命名空间所有者的私钥，无法和资产仓库完成签约，只能先上传，事后由命名空间所有者完成签名；

    """

    def Search(self, request, context):
        """*
        检索数字内容，基于数字内容的元信息检索，比如哈希值、时间、类型、名称等, 如果什么条件都不传入，则按照默认的排序顺序，返回第一个10条记录。
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Sign(self, request, context):
        """*
        以事务的形式和存储供应商签订协议并入库，当所有资产块入库成功后，资产的信息发送到后端服务签字确认，涵盖了新的资产和新的版本入库；
        1、根据规则，自动生成新的版本，资产身份不变，但是资产内容的哈希值会变
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Update(self, request, context):
        """*
        更新资产元信息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Detail(self, request, context):
        """*
        获得资产详细信息，提供该接口是为了更灵活处理资产信息，资产信息的复杂主要是几个方面：
        1、资产分块，资产的块信息可能会很大
        2、多版本，资产描述信息也会很大
        3、分散存储，如果资产过大，可能会被存储到不同的供应商
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Delete(self, request, context):
        """*
        删除资产，不回立即删除，而是放入回收站；资产支持多版本，在删除的时候，采取头或者尾部删除，不能从中间删除，确保版本的链条能够正常工作；
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AssetServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Search": grpc.unary_unary_rpc_method_handler(
            servicer.Search,
            request_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.SearchAssetRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.SearchAssetResponse.SerializeToString,
        ),
        "Sign": grpc.unary_unary_rpc_method_handler(
            servicer.Sign,
            request_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.SignAssetRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.SignAssetResponse.SerializeToString,
        ),
        "Update": grpc.unary_unary_rpc_method_handler(
            servicer.Update,
            request_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.UpdateAssetRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.UpdateAssetResponse.SerializeToString,
        ),
        "Detail": grpc.unary_unary_rpc_method_handler(
            servicer.Detail,
            request_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.AssetDetailRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.AssetDetailResponse.SerializeToString,
        ),
        "Delete": grpc.unary_unary_rpc_method_handler(
            servicer.Delete,
            request_deserializer=yeying_dot_api_dot_asset_dot_asset__pb2.DeleteAssetRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_asset__pb2.DeleteAssetResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.asset.Asset", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.asset.Asset", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Asset(object):
    """*

    整个资产仓库基于分布式数字身份和资产内容哈希驱动，并能够在不同资产仓库间转移

    开放的分散式仓库网络的接口设计，参考了现实世界中的仓库，逻辑如下：
    1、数字资产有两个标识，一个是数字资产的身份标识，可以是分布式数字身份，也可以是用户自定义的身份ID，另一个是数字资产内容的哈希值；
    2、数字资产入库，发送到指定存储网络中的节点，可以指定副本数量，一方面保证内容不会因为单个节点故障而丢失，另外也保证内容的可访问性；
    3、存储复用，如果两份资产哈希值一样，分两种情况来看，如果资产的所有者一样，则仓库会主动告知身份持有者存在重复，如果资产的所有者不同，会增加引用；
    4、授权数字资产，所有者和使用者立交易关系，确保使用者根据指定的策略访问数据，仓库会统计数字资产的使用情况，比如统计内容取（浏览）的次数评估内容热度
    ，或者统计内容存的次数（收藏）评估内容质量，目的是更好的分配存储资源；

    仓库使用场景：
    1、创作场景，知识产权证明
    2、代码包分发场景，比如软件包，模型包等
    3、数字资产，类似nft等

    资产定位逻辑：

    采用三元组唯一定位，(用户身份、命名空间、哈希值)
    命名空间的定位逻辑：某个用户下面是唯一的，命名空间所有者，可以指定多个参与者，用于存储完成某项工作生成资产数据，这些资产数据属于命名空间所有者
    资产的定位逻辑：每个命名空间是隔离的，同一个所有者，同一个命名空间，资产哈希值必须唯一
    资产块的定位逻辑：每个命名空间是隔离的，用一个所有者，同一个命名空间，资产块是唯一的，资产块维持一个引用计数，其逻辑如下：
    - 当有一个新资产放入命名空间，则引用计数加1；
    - 当有一个老资产移出命名空间，则引用计数减1；
    当某个资产块的引用计数为0，表示没有和资产仓库服务签约，只是临时存储，通常分块上传完成以后就会立即签约，但是考虑委托第三方服务生成的数据直接放到命名
    空间，第三方服务没有命名空间所有者的私钥，无法和资产仓库完成签约，只能先上传，事后由命名空间所有者完成签名；

    """

    @staticmethod
    def Search(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Asset/Search",
            yeying_dot_api_dot_asset_dot_asset__pb2.SearchAssetRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_asset__pb2.SearchAssetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Sign(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Asset/Sign",
            yeying_dot_api_dot_asset_dot_asset__pb2.SignAssetRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_asset__pb2.SignAssetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Update(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Asset/Update",
            yeying_dot_api_dot_asset_dot_asset__pb2.UpdateAssetRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_asset__pb2.UpdateAssetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Detail(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Asset/Detail",
            yeying_dot_api_dot_asset_dot_asset__pb2.AssetDetailRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_asset__pb2.AssetDetailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Delete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Asset/Delete",
            yeying_dot_api_dot_asset_dot_asset__pb2.DeleteAssetRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_asset__pb2.DeleteAssetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class SearchRequest(_message.Message):
    __slots__ = ("owner",)
    OWNER_FIELD_NUMBER: _ClassVar[int]
    owner: str
    def __init__(self, owner: _Optional[str] = ...) -> None: ...

class SearchResponse(_message.Message):
    __slots__ = ("status", "topicMetadata")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TOPICMETADATA_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    topicMetadata: _containers.RepeatedCompositeFieldContainer[TopicMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        topicMetadata: _Optional[_Iterable[_Union[TopicMetadata, _Mapping]]] = ...,
    ) -> None: ...

class UnsubscribeRequest(_message.Message):
    __slots__ = ("owner", "name")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    owner: str
    name: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, owner: _Optional[str] = ..., name: _Optional[_Iterable[str]] = ...) -> None: ...

class UnsubscribeResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class TopicMetadata(_message.Message):
    __slots__ = ("name", "format", "expression", "status")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    name: str
    format: _containers.RepeatedScalarFieldContainer[_code_pb2.DigitalFormatEnum]
    expression: str
    status: _code_pb2.ContractStatusEnum
    def __init__(
        self,
        name: _Optional[str] = ...,
        format: _Optional[_Iterable[_Union[_code_pb2.DigitalFormatEnum, str]]] = ...,
        expression: _Optional[str] = ...,
        status: _Optional[_Union[_code_pb2.ContractStatusEnum, str]] = ...,
    ) -> None: ...

class SubscribeRequest(_message.Message):
    __slots__ = ("owner", "topicMetadata")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    TOPICMETADATA_FIELD_NUMBER: _ClassVar[int]
    owner: str
    topicMetadata: _containers.RepeatedCompositeFieldContainer[TopicMetadata]
    def __init__(
        self, owner: _Optional[str] = ..., topicMetadata: _Optional[_Iterable[_Union[TopicMetadata, _Mapping]]] = ...
    ) -> None: ...

class SubscribeResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendMailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SendMailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SendMailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SendMailRequestBody(_message.Message):
    __slots__ = ("toMail",)
    TOMAIL_FIELD_NUMBER: _ClassVar[int]
    toMail: str
    def __init__(self, toMail: _Optional[str] = ...) -> None: ...

class SendMailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SendMailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SendMailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SendMailResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class VerifyMailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: VerifyMailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[VerifyMailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class VerifyMailRequestBody(_message.Message):
    __slots__ = ("toMail", "code")
    TOMAIL_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    toMail: str
    code: str
    def __init__(self, toMail: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class VerifyMailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: VerifyMailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[VerifyMailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class VerifyMailResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/social/social.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/social/social.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/social/social.proto\x12\x11yeying.api.social\x1a\x1fyeying/api/common/message.proto"\x14\n\x12MakeFriendsRequest"\x15\n\x13MakeFriendsResponse"\x13\n\x11GetFriendsRequest"\x13\n\x11GetFriendResponse2\xc4\x01\n\x06Social\x12^\n\x0bMakeFriends\x12%.yeying.api.social.MakeFriendsRequest\x1a&.yeying.api.social.MakeFriendsResponse"\x00\x12Z\n\nGetFriends\x12$.yeying.api.social.GetFriendsRequest\x1a$.yeying.api.social.GetFriendResponse"\x00\x42\x13Z\x11yeying/api/socialb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.social.social_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/social"
    _globals["_MAKEFRIENDSREQUEST"]._serialized_start = 86
    _globals["_MAKEFRIENDSREQUEST"]._serialized_end = 106
    _globals["_MAKEFRIENDSRESPONSE"]._serialized_start = 108
    _globals["_MAKEFRIENDSRESPONSE"]._serialized_end = 129
    _globals["_GETFRIENDSREQUEST"]._serialized_start = 131
    _globals["_GETFRIENDSREQUEST"]._serialized_end = 150
    _globals["_GETFRIENDRESPONSE"]._serialized_start = 152
    _globals["_GETFRIENDRESPONSE"]._serialized_end = 171
    _globals["_SOCIAL"]._serialized_start = 174
    _globals["_SOCIAL"]._serialized_end = 370
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/asset.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/asset.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/asset/asset.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"~\n\x12SearchAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.SearchAssetRequestBody"\x81\x01\n\x16SearchAssetRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.asset.SearchAssetCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"}\n\x14SearchAssetCondition\x12\x34\n\x06\x66ormat\x18\x01 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t"\x80\x01\n\x13SearchAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.SearchAssetResponseBody"}\n\x17SearchAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12/\n\x06\x61ssets\x18\x02 \x03(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"z\n\x10SignAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.asset.SignAssetRequestBody"F\n\x14SignAssetRequestBody\x12.\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"|\n\x11SignAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.SignAssetResponseBody"z\n\x15SignAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x61sset\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"~\n\x12UpdateAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.UpdateAssetRequestBody"H\n\x16UpdateAssetRequestBody\x12.\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"\x80\x01\n\x13UpdateAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.UpdateAssetResponseBody"|\n\x17UpdateAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x61sset\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"~\n\x12\x41ssetDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.AssetDetailRequestBody";\n\x16\x41ssetDetailRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x80\x01\n\x13\x41ssetDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.AssetDetailResponseBody"|\n\x17\x41ssetDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x61sset\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"~\n\x12\x44\x65leteAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.DeleteAssetRequestBody";\n\x16\x44\x65leteAssetRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x80\x01\n\x13\x44\x65leteAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.DeleteAssetResponseBody"L\n\x17\x44\x65leteAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\xd2\x02\n\rAssetMetadata\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x12\n\nparentHash\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06\x63hunks\x18\x07 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x34\n\x06\x66ormat\x18\t \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x0c\n\x04size\x18\n \x01(\x04\x12\x11\n\tcreatedAt\x18\x0b \x01(\t\x12\x11\n\tupdatedAt\x18\x0c \x01(\t\x12\x12\n\nchunkCount\x18\r \x01(\r\x12\x11\n\tchunkSize\x18\x0e \x01(\r\x12\x13\n\x0bisEncrypted\x18\x0f \x01(\x08\x12\x11\n\tsignature\x18\x10 \x01(\t2\xbe\x03\n\x05\x41sset\x12W\n\x06Search\x12$.yeying.api.asset.SearchAssetRequest\x1a%.yeying.api.asset.SearchAssetResponse"\x00\x12Q\n\x04Sign\x12".yeying.api.asset.SignAssetRequest\x1a#.yeying.api.asset.SignAssetResponse"\x00\x12W\n\x06Update\x12$.yeying.api.asset.UpdateAssetRequest\x1a%.yeying.api.asset.UpdateAssetResponse"\x00\x12W\n\x06\x44\x65tail\x12$.yeying.api.asset.AssetDetailRequest\x1a%.yeying.api.asset.AssetDetailResponse"\x00\x12W\n\x06\x44\x65lete\x12$.yeying.api.asset.DeleteAssetRequest\x1a%.yeying.api.asset.DeleteAssetResponse"\x00\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.asset_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_SEARCHASSETREQUEST"]._serialized_start = 113
    _globals["_SEARCHASSETREQUEST"]._serialized_end = 239
    _globals["_SEARCHASSETREQUESTBODY"]._serialized_start = 242
    _globals["_SEARCHASSETREQUESTBODY"]._serialized_end = 371
    _globals["_SEARCHASSETCONDITION"]._serialized_start = 373
    _globals["_SEARCHASSETCONDITION"]._serialized_end = 498
    _globals["_SEARCHASSETRESPONSE"]._serialized_start = 501
    _globals["_SEARCHASSETRESPONSE"]._serialized_end = 629
    _globals["_SEARCHASSETRESPONSEBODY"]._serialized_start = 631
    _globals["_SEARCHASSETRESPONSEBODY"]._serialized_end = 756
    _globals["_SIGNASSETREQUEST"]._serialized_start = 758
    _globals["_SIGNASSETREQUEST"]._serialized_end = 880
    _globals["_SIGNASSETREQUESTBODY"]._serialized_start = 882
    _globals["_SIGNASSETREQUESTBODY"]._serialized_end = 952
    _globals["_SIGNASSETRESPONSE"]._serialized_start = 954
    _globals["_SIGNASSETRESPONSE"]._serialized_end = 1078
    _globals["_SIGNASSETRESPONSEBODY"]._serialized_start = 1080
    _globals["_SIGNASSETRESPONSEBODY"]._serialized_end = 1202
    _globals["_UPDATEASSETREQUEST"]._serialized_start = 1204
    _globals["_UPDATEASSETREQUEST"]._serialized_end = 1330
    _globals["_UPDATEASSETREQUESTBODY"]._serialized_start = 1332
    _globals["_UPDATEASSETREQUESTBODY"]._serialized_end = 1404
    _globals["_UPDATEASSETRESPONSE"]._serialized_start = 1407
    _globals["_UPDATEASSETRESPONSE"]._serialized_end = 1535
    _globals["_UPDATEASSETRESPONSEBODY"]._serialized_start = 1537
    _globals["_UPDATEASSETRESPONSEBODY"]._serialized_end = 1661
    _globals["_ASSETDETAILREQUEST"]._serialized_start = 1663
    _globals["_ASSETDETAILREQUEST"]._serialized_end = 1789
    _globals["_ASSETDETAILREQUESTBODY"]._serialized_start = 1791
    _globals["_ASSETDETAILREQUESTBODY"]._serialized_end = 1850
    _globals["_ASSETDETAILRESPONSE"]._serialized_start = 1853
    _globals["_ASSETDETAILRESPONSE"]._serialized_end = 1981
    _globals["_ASSETDETAILRESPONSEBODY"]._serialized_start = 1983
    _globals["_ASSETDETAILRESPONSEBODY"]._serialized_end = 2107
    _globals["_DELETEASSETREQUEST"]._serialized_start = 2109
    _globals["_DELETEASSETREQUEST"]._serialized_end = 2235
    _globals["_DELETEASSETREQUESTBODY"]._serialized_start = 2237
    _globals["_DELETEASSETREQUESTBODY"]._serialized_end = 2296
    _globals["_DELETEASSETRESPONSE"]._serialized_start = 2299
    _globals["_DELETEASSETRESPONSE"]._serialized_end = 2427
    _globals["_DELETEASSETRESPONSEBODY"]._serialized_start = 2429
    _globals["_DELETEASSETRESPONSEBODY"]._serialized_end = 2505
    _globals["_ASSETMETADATA"]._serialized_start = 2508
    _globals["_ASSETMETADATA"]._serialized_end = 2846
    _globals["_ASSET"]._serialized_start = 2849
    _globals["_ASSET"]._serialized_end = 3295
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class EventTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TYPE_UNKNOWN: _ClassVar[EventTypeEnum]
    EVENT_TYPE_REMIND: _ClassVar[EventTypeEnum]
    EVENT_TYPE_NOTIFY: _ClassVar[EventTypeEnum]
    EVENT_TYPE_APPLY: _ClassVar[EventTypeEnum]
    EVENT_TYPE_CUSTOM: _ClassVar[EventTypeEnum]

class ApplyActionEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    APPLY_ACTION_UNKNOWN: _ClassVar[ApplyActionEnum]
    APPLY_ACTION_PASSED: _ClassVar[ApplyActionEnum]
    APPLY_ACTION_REFUSED: _ClassVar[ApplyActionEnum]

class NotifyActionEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NOTIFY_ACTION_UNKNOWN: _ClassVar[NotifyActionEnum]
    NOTIFY_ACTION_ADD: _ClassVar[NotifyActionEnum]
    NOTIFY_ACTION_DEL: _ClassVar[NotifyActionEnum]
    NOTIFY_ACTION_MOD: _ClassVar[NotifyActionEnum]

EVENT_TYPE_UNKNOWN: EventTypeEnum
EVENT_TYPE_REMIND: EventTypeEnum
EVENT_TYPE_NOTIFY: EventTypeEnum
EVENT_TYPE_APPLY: EventTypeEnum
EVENT_TYPE_CUSTOM: EventTypeEnum
APPLY_ACTION_UNKNOWN: ApplyActionEnum
APPLY_ACTION_PASSED: ApplyActionEnum
APPLY_ACTION_REFUSED: ApplyActionEnum
NOTIFY_ACTION_UNKNOWN: NotifyActionEnum
NOTIFY_ACTION_ADD: NotifyActionEnum
NOTIFY_ACTION_DEL: NotifyActionEnum
NOTIFY_ACTION_MOD: NotifyActionEnum

class EventMetadata(_message.Message):
    __slots__ = (
        "uid",
        "type",
        "producers",
        "consumers",
        "signature",
        "extend",
        "createdAt",
        "processedAt",
        "notifyContent",
        "applyContent",
        "customContent",
        "notifyOpinion",
        "applyOpinion",
        "customOpinion",
    )
    UID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PRODUCERS_FIELD_NUMBER: _ClassVar[int]
    CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    EXTEND_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    PROCESSEDAT_FIELD_NUMBER: _ClassVar[int]
    NOTIFYCONTENT_FIELD_NUMBER: _ClassVar[int]
    APPLYCONTENT_FIELD_NUMBER: _ClassVar[int]
    CUSTOMCONTENT_FIELD_NUMBER: _ClassVar[int]
    NOTIFYOPINION_FIELD_NUMBER: _ClassVar[int]
    APPLYOPINION_FIELD_NUMBER: _ClassVar[int]
    CUSTOMOPINION_FIELD_NUMBER: _ClassVar[int]
    uid: str
    type: EventTypeEnum
    producers: _containers.RepeatedScalarFieldContainer[str]
    consumers: _containers.RepeatedScalarFieldContainer[str]
    signature: EventSignature
    extend: str
    createdAt: str
    processedAt: str
    notifyContent: NotifyContent
    applyContent: ApplyContent
    customContent: CustomContent
    notifyOpinion: NotifyOpinion
    applyOpinion: ApplyOpinion
    customOpinion: CustomOpinion
    def __init__(
        self,
        uid: _Optional[str] = ...,
        type: _Optional[_Union[EventTypeEnum, str]] = ...,
        producers: _Optional[_Iterable[str]] = ...,
        consumers: _Optional[_Iterable[str]] = ...,
        signature: _Optional[_Union[EventSignature, _Mapping]] = ...,
        extend: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        processedAt: _Optional[str] = ...,
        notifyContent: _Optional[_Union[NotifyContent, _Mapping]] = ...,
        applyContent: _Optional[_Union[ApplyContent, _Mapping]] = ...,
        customContent: _Optional[_Union[CustomContent, _Mapping]] = ...,
        notifyOpinion: _Optional[_Union[NotifyOpinion, _Mapping]] = ...,
        applyOpinion: _Optional[_Union[ApplyOpinion, _Mapping]] = ...,
        customOpinion: _Optional[_Union[CustomOpinion, _Mapping]] = ...,
    ) -> None: ...

class SignatureObject(_message.Message):
    __slots__ = (
        "uid",
        "type",
        "producers",
        "consumers",
        "signature",
        "extend",
        "createdAt",
        "processedAt",
        "opinion",
        "content",
    )
    UID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PRODUCERS_FIELD_NUMBER: _ClassVar[int]
    CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    EXTEND_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    PROCESSEDAT_FIELD_NUMBER: _ClassVar[int]
    OPINION_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    uid: str
    type: EventTypeEnum
    producers: _containers.RepeatedScalarFieldContainer[str]
    consumers: _containers.RepeatedScalarFieldContainer[str]
    signature: bytes
    extend: str
    createdAt: str
    processedAt: str
    opinion: bytes
    content: bytes
    def __init__(
        self,
        uid: _Optional[str] = ...,
        type: _Optional[_Union[EventTypeEnum, str]] = ...,
        producers: _Optional[_Iterable[str]] = ...,
        consumers: _Optional[_Iterable[str]] = ...,
        signature: _Optional[bytes] = ...,
        extend: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        processedAt: _Optional[str] = ...,
        opinion: _Optional[bytes] = ...,
        content: _Optional[bytes] = ...,
    ) -> None: ...

class EventSignature(_message.Message):
    __slots__ = ("producers", "consumers")
    PRODUCERS_FIELD_NUMBER: _ClassVar[int]
    CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    producers: _containers.RepeatedScalarFieldContainer[str]
    consumers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self, producers: _Optional[_Iterable[str]] = ..., consumers: _Optional[_Iterable[str]] = ...
    ) -> None: ...

class CustomContent(_message.Message):
    __slots__ = ("name", "object")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    name: str
    object: str
    def __init__(self, name: _Optional[str] = ..., object: _Optional[str] = ...) -> None: ...

class ApplyContent(_message.Message):
    __slots__ = ("applier",)
    APPLIER_FIELD_NUMBER: _ClassVar[int]
    applier: str
    def __init__(self, applier: _Optional[str] = ...) -> None: ...

class NotifyContent(_message.Message):
    __slots__ = ("name", "items")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    name: str
    items: _containers.RepeatedCompositeFieldContainer[NotifyItem]
    def __init__(
        self, name: _Optional[str] = ..., items: _Optional[_Iterable[_Union[NotifyItem, _Mapping]]] = ...
    ) -> None: ...

class NotifyItem(_message.Message):
    __slots__ = ("uid", "action")
    UID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    uid: str
    action: NotifyActionEnum
    def __init__(self, uid: _Optional[str] = ..., action: _Optional[_Union[NotifyActionEnum, str]] = ...) -> None: ...

class ProduceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ProduceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ProduceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ProduceRequestBody(_message.Message):
    __slots__ = ("event",)
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event: EventMetadata
    def __init__(self, event: _Optional[_Union[EventMetadata, _Mapping]] = ...) -> None: ...

class ProduceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ProduceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ProduceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ProduceResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class ConsumeRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ConsumeRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ConsumeRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ConsumeRequestBody(_message.Message):
    __slots__ = ("metadata",)
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: EventMetadata
    def __init__(self, metadata: _Optional[_Union[EventMetadata, _Mapping]] = ...) -> None: ...

class NotifyOpinion(_message.Message):
    __slots__ = ("processed",)
    PROCESSED_FIELD_NUMBER: _ClassVar[int]
    processed: str
    def __init__(self, processed: _Optional[str] = ...) -> None: ...

class ApplyOpinion(_message.Message):
    __slots__ = ("action", "cause", "processed")
    ACTION_FIELD_NUMBER: _ClassVar[int]
    CAUSE_FIELD_NUMBER: _ClassVar[int]
    PROCESSED_FIELD_NUMBER: _ClassVar[int]
    action: ApplyActionEnum
    cause: str
    processed: str
    def __init__(
        self,
        action: _Optional[_Union[ApplyActionEnum, str]] = ...,
        cause: _Optional[str] = ...,
        processed: _Optional[str] = ...,
    ) -> None: ...

class CustomOpinion(_message.Message):
    __slots__ = ("name", "object")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    name: str
    object: str
    def __init__(self, name: _Optional[str] = ..., object: _Optional[str] = ...) -> None: ...

class ConsumeResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ConsumeResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ConsumeResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ConsumeResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/archive.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/archive.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/apps/zuoyepigai/archive.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x88\x01\n\x12\x41rchiveListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.ArchiveListRequestBody"\x99\x01\n\x16\x41rchiveListRequestBody\x12\x12\n\nteacherDid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\tpageIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"\x8a\x01\n\x13\x41rchiveListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.ArchiveListResponseBody"\x96\x01\n\x17\x41rchiveListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04list\x18\x02 \x03(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata\x12\r\n\x05total\x18\x03 \x01(\x04"\x8c\x01\n\x14\x41rchiveDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ArchiveDetailRequestBody"\'\n\x18\x41rchiveDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x41rchiveDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ArchiveDetailResponseBody"\x89\x01\n\x19\x41rchiveDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x9a\x01\n\x1b\x41rchiveDetailStudentRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12I\n\x04\x62ody\x18\x02 \x01(\x0b\x32;.yeying.api.apps.zuoyepigai.ArchiveDetailStudentRequestBody"5\n\x1f\x41rchiveDetailStudentRequestBody\x12\x12\n\nstudentDid\x18\x01 \x01(\t"\x9c\x01\n\x1c\x41rchiveDetailStudentResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12J\n\x04\x62ody\x18\x02 \x01(\x0b\x32<.yeying.api.apps.zuoyepigai.ArchiveDetailStudentResponseBody"\x90\x01\n ArchiveDetailStudentResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x86\x01\n\x11\x41rchiveAddRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.ArchiveAddRequestBody"R\n\x15\x41rchiveAddRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x88\x01\n\x12\x41rchiveAddResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.ArchiveAddResponseBody"\x86\x01\n\x16\x41rchiveAddResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x8c\x01\n\x14\x41rchiveDeleteRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ArchiveDeleteRequestBody"\'\n\x18\x41rchiveDeleteRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x41rchiveDeleteResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ArchiveDeleteResponseBody"\x89\x01\n\x19\x41rchiveDeleteResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x8c\x01\n\x14\x41rchiveUpdateRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ArchiveUpdateRequestBody"U\n\x18\x41rchiveUpdateRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x8e\x01\n\x15\x41rchiveUpdateResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ArchiveUpdateResponseBody"\x89\x01\n\x19\x41rchiveUpdateResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata2\xbb\x05\n\x07\x41rchive\x12i\n\x04List\x12..yeying.api.apps.zuoyepigai.ArchiveListRequest\x1a/.yeying.api.apps.zuoyepigai.ArchiveListResponse"\x00\x12o\n\x06\x44\x65tail\x12\x30.yeying.api.apps.zuoyepigai.ArchiveDetailRequest\x1a\x31.yeying.api.apps.zuoyepigai.ArchiveDetailResponse"\x00\x12\x89\x01\n\x12\x44\x65tailByStudentDid\x12\x37.yeying.api.apps.zuoyepigai.ArchiveDetailStudentRequest\x1a\x38.yeying.api.apps.zuoyepigai.ArchiveDetailStudentResponse"\x00\x12\x66\n\x03\x41\x64\x64\x12-.yeying.api.apps.zuoyepigai.ArchiveAddRequest\x1a..yeying.api.apps.zuoyepigai.ArchiveAddResponse"\x00\x12o\n\x06\x44\x65lete\x12\x30.yeying.api.apps.zuoyepigai.ArchiveDeleteRequest\x1a\x31.yeying.api.apps.zuoyepigai.ArchiveDeleteResponse"\x00\x12o\n\x06Update\x12\x30.yeying.api.apps.zuoyepigai.ArchiveUpdateRequest\x1a\x31.yeying.api.apps.zuoyepigai.ArchiveUpdateResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.archive_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ARCHIVELISTREQUEST"]._serialized_start = 177
    _globals["_ARCHIVELISTREQUEST"]._serialized_end = 313
    _globals["_ARCHIVELISTREQUESTBODY"]._serialized_start = 316
    _globals["_ARCHIVELISTREQUESTBODY"]._serialized_end = 469
    _globals["_ARCHIVELISTRESPONSE"]._serialized_start = 472
    _globals["_ARCHIVELISTRESPONSE"]._serialized_end = 610
    _globals["_ARCHIVELISTRESPONSEBODY"]._serialized_start = 613
    _globals["_ARCHIVELISTRESPONSEBODY"]._serialized_end = 763
    _globals["_ARCHIVEDETAILREQUEST"]._serialized_start = 766
    _globals["_ARCHIVEDETAILREQUEST"]._serialized_end = 906
    _globals["_ARCHIVEDETAILREQUESTBODY"]._serialized_start = 908
    _globals["_ARCHIVEDETAILREQUESTBODY"]._serialized_end = 947
    _globals["_ARCHIVEDETAILRESPONSE"]._serialized_start = 950
    _globals["_ARCHIVEDETAILRESPONSE"]._serialized_end = 1092
    _globals["_ARCHIVEDETAILRESPONSEBODY"]._serialized_start = 1095
    _globals["_ARCHIVEDETAILRESPONSEBODY"]._serialized_end = 1232
    _globals["_ARCHIVEDETAILSTUDENTREQUEST"]._serialized_start = 1235
    _globals["_ARCHIVEDETAILSTUDENTREQUEST"]._serialized_end = 1389
    _globals["_ARCHIVEDETAILSTUDENTREQUESTBODY"]._serialized_start = 1391
    _globals["_ARCHIVEDETAILSTUDENTREQUESTBODY"]._serialized_end = 1444
    _globals["_ARCHIVEDETAILSTUDENTRESPONSE"]._serialized_start = 1447
    _globals["_ARCHIVEDETAILSTUDENTRESPONSE"]._serialized_end = 1603
    _globals["_ARCHIVEDETAILSTUDENTRESPONSEBODY"]._serialized_start = 1606
    _globals["_ARCHIVEDETAILSTUDENTRESPONSEBODY"]._serialized_end = 1750
    _globals["_ARCHIVEADDREQUEST"]._serialized_start = 1753
    _globals["_ARCHIVEADDREQUEST"]._serialized_end = 1887
    _globals["_ARCHIVEADDREQUESTBODY"]._serialized_start = 1889
    _globals["_ARCHIVEADDREQUESTBODY"]._serialized_end = 1971
    _globals["_ARCHIVEADDRESPONSE"]._serialized_start = 1974
    _globals["_ARCHIVEADDRESPONSE"]._serialized_end = 2110
    _globals["_ARCHIVEADDRESPONSEBODY"]._serialized_start = 2113
    _globals["_ARCHIVEADDRESPONSEBODY"]._serialized_end = 2247
    _globals["_ARCHIVEDELETEREQUEST"]._serialized_start = 2250
    _globals["_ARCHIVEDELETEREQUEST"]._serialized_end = 2390
    _globals["_ARCHIVEDELETEREQUESTBODY"]._serialized_start = 2392
    _globals["_ARCHIVEDELETEREQUESTBODY"]._serialized_end = 2431
    _globals["_ARCHIVEDELETERESPONSE"]._serialized_start = 2434
    _globals["_ARCHIVEDELETERESPONSE"]._serialized_end = 2576
    _globals["_ARCHIVEDELETERESPONSEBODY"]._serialized_start = 2579
    _globals["_ARCHIVEDELETERESPONSEBODY"]._serialized_end = 2716
    _globals["_ARCHIVEUPDATEREQUEST"]._serialized_start = 2719
    _globals["_ARCHIVEUPDATEREQUEST"]._serialized_end = 2859
    _globals["_ARCHIVEUPDATEREQUESTBODY"]._serialized_start = 2861
    _globals["_ARCHIVEUPDATEREQUESTBODY"]._serialized_end = 2946
    _globals["_ARCHIVEUPDATERESPONSE"]._serialized_start = 2949
    _globals["_ARCHIVEUPDATERESPONSE"]._serialized_end = 3091
    _globals["_ARCHIVEUPDATERESPONSEBODY"]._serialized_start = 3094
    _globals["_ARCHIVEUPDATERESPONSEBODY"]._serialized_end = 3231
    _globals["_ARCHIVE"]._serialized_start = 3234
    _globals["_ARCHIVE"]._serialized_end = 3933
# @@protoc_insertion_point(module_scope)
